import { type MaybeRefOrGetter } from 'vue';
import type { UseHighlightOptions, ShikiHighlighter } from './types';
/**
 * Lazy-load shiki instance.
 *
 * You can use this utility both in `server/` and vue app code.
 *
 * @example
 * ```vue
 * <script setup>
 * const highlighter = await getShikiHighlighter()
 * const html = highlighter.highlight(`const hello = 'shiki'`, { lang: 'js' })
 * </script>
 * ```
 *
 * @example
 * ```ts
 * // server/api/highlight.ts
 * export default defineEventHandler(async (event) => {
 *   const highlighter = await getShikiHighlighter()
 *   return highlighter.highlight(`const hello = 'shiki'`, { lang: 'js' })
 * })
 * ```
 */
export declare function getShikiHighlighter(): Promise<ShikiHighlighter>;
/**
 * Return a lazy highlighted code ref (only usable in Vue)
 *
 * @example
 * ```vue
 * <script setup>
 * const code = ref(`const hello = 'shiki'`)
 * const highlighted = await useShikiHighlighted(code)
 * </script>
 * ```
 */
export declare function useShikiHighlighted(code: MaybeRefOrGetter<string | undefined>, options?: UseHighlightOptions): Promise<import("vue").Ref<string>>;
/**
 * Dynamically loading languages when options.dynamic is true.
 *
 * @example
 * ```vue
 * <script setup>
 * const highlighter = await getShikiHighlighter()
 * await loadShikiLanguages(highlighter, "tsx", "vue");
 * </script>
 * ```
 */
export declare function loadShikiLanguages(highlighter: ShikiHighlighter, ...langs: string[]): Promise<void>;
